@@ -1,19 +1,16 @@
-use clap::{arg, crate_version, App, Arg};
+use clap::{arg, crate_version, Arg, Command};
 
 const FOOTER: &str =
-	"For the configuration file syntax, please visit https://github.com/insomnimus/midnote";
+	"For the configuration file syntax, visit https://github.com/insomnimus/midnote";
 
-pub fn new() -> App<'static> {
-	App::new("midnote")
+pub fn new() -> Command<'static> {
+	Command::new("midnote")
 		.about("View and play notes in a MIDI track.")
 		.after_long_help(FOOTER)
 		.version(crate_version!())
 		.args(&[
 			arg!(-c --config [PATH] "Path to a config file (*.json)."),
-			Arg::new("no-color")
-				.short('C')
-				.long("no-color")
-				.help("Do not use colored output."),
+			arg!(-C --"no-color" "Do not use colored output."),
 			arg!(-l --list "List available MIDI output devices."),
 			arg!(-d --device <NO> "The MIDI output device.")
 				.default_value("0")
